@@ -2,7 +2,9 @@ use strict;
 use warnings;
 package Getopt::Long::Descriptive;
 # ABSTRACT: Getopt::Long, but simpler and more powerful
-$Getopt::Long::Descriptive::VERSION = '0.102';
+$Getopt::Long::Descriptive::VERSION = '0.106';
+use v5.10;
+
 use Carp qw(carp croak);
 use File::Basename ();
 use Getopt::Long 2.33;
@@ -131,7 +133,9 @@ use Getopt::Long::Descriptive::Usage;
 #pod than causing a blank line to appear in the usage message.
 #pod
 #pod If the option specification contains only one element, it will be printed in
-#pod the usage message with no other effect.
+#pod the usage message with no other effect.  If the element is a reference, its
+#pod referent will be printed as-is.  Otherwise, it will be reformatted like other
+#pod text in the usage message.
 #pod
 #pod If the option specification contains a third element, it adds extra constraints
 #pod or modifiers to the interpretation and validation of the value.  These are the
@@ -285,6 +289,16 @@ my %CONSTRAINT = (
 
 our $MungeOptions = 1;
 
+our $TERM_WIDTH;
+{
+  if (eval { require Term::ReadKey; 1 }) {
+    my ($width) = Term::ReadKey::GetTerminalSize();
+    $TERM_WIDTH = $width;
+  } else {
+    $TERM_WIDTH = $ENV{COLUMNS} || 80;
+  }
+}
+
 sub _nohidden {
   return grep { ! $_->{constraint}->{hidden} } @_;
 }
@@ -317,12 +331,10 @@ sub _strip_assignment {
   (my $copy = $str) =~ s{$SPEC_RE}{};
 
   if (wantarray) {
-      my $len = length $copy;
-      my $assignment = substr $str, $len;
-      if (!defined($assignment)) {
-          $assignment = '';
-      }
-      return ($copy, $assignment);
+    my $len = length $copy;
+    my $assignment = substr($str, $len) // q{};
+
+    return ($copy, $assignment);
   }
   return $copy;
 }
@@ -376,6 +388,10 @@ sub _build_describe_options {
           }
           $one_opt->{constraint}->{one_of} = $opt->{name};
           push @opts, $one_opt;
+
+          # Ensure that we generate accessors for all one_of sub-options
+          $method_map{ $one_opt->{name} } = undef
+            unless $one_opt->{desc} eq 'spacer';
         }
       }
 
@@ -412,13 +428,23 @@ sub _build_describe_options {
       grep { $_->{desc} ne 'spacer' }
       _nohidden(@opts);
 
-    my $short = join q{},
-      sort  { lc $a cmp lc $b or $a cmp $b }
-      grep  { /^.$/ }
+    my @options =
       map   { split /\|/ }
       map   { scalar __PACKAGE__->_strip_assignment($_) }
       @specs;
 
+    my %opt_count;
+    $opt_count{$_}++ for @options;
+    my @redundant = sort grep {; $opt_count{$_} > 1 } keys %opt_count;
+
+    warn "Getopt::Long::Descriptive was configured with these ambiguous options: @redundant\n"
+      if @redundant;
+
+    my $short = join q{},
+      sort  { lc $a cmp lc $b or $a cmp $b }
+      grep  { /^.$/ }
+      @options;
+
     my $long = grep /\b[^|]{2,}/, @specs;
 
     my %replace = (
@@ -431,9 +457,8 @@ sub _build_describe_options {
     );
 
     (my $str = $format) =~ s<%(.)><
-      defined $replace{$1}
-      ? $replace{$1}
-      : Carp::croak("unknown sequence %$1 in first argument to describe_options")
+      $replace{$1}
+      // Carp::croak("unknown sequence %$1 in first argument to describe_options")
     >ge;
 
     $str =~ s/[\x20\t]{2,}/ /g;
@@ -474,7 +499,7 @@ sub _build_describe_options {
         given_keys => \@given_keys,
         parent_of  => \%parent_of,
       );
-      next unless (defined($new) || exists($return{$name}));
+      next unless defined $new || exists $return{$name};
       $return{$name} = $new;
 
       if ($is_shortcircuit) {
@@ -696,7 +721,7 @@ Getopt::Long::Descriptive - Getopt::Long, but simpler and more powerful
 
 =head1 VERSION
 
-version 0.102
+version 0.106
 
 =head1 SYNOPSIS
 
@@ -816,7 +841,9 @@ If the option specification (arrayref) is empty, it will have no effect other
 than causing a blank line to appear in the usage message.
 
 If the option specification contains only one element, it will be printed in
-the usage message with no other effect.
+the usage message with no other effect.  If the element is a reference, its
+referent will be printed as-is.  Otherwise, it will be reformatted like other
+text in the usage message.
 
 If the option specification contains a third element, it adds extra constraints
 or modifiers to the interpretation and validation of the value.  These are the
@@ -984,7 +1011,7 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Arthur Axel 'fREW' Schmidt Dave Rolsky Diab Jerius Hans Dieter Pearcey Harley Pig hdp@cpan.org Karen Etheridge Niels Thykier Olaf Alders Roman Hubacek Smylers Thomas Neumann zhouzhen1
+=for stopwords Arthur Axel 'fREW' Schmidt Dave Rolsky Diab Jerius Hans Dieter Pearcey Harley Pig hdp@cpan.org Karen Etheridge Michael McClimon Niels Thykier Olaf Alders Ricardo Signes Roman Hubacek Smylers Thomas Neumann zhouzhen1
 
 =over 4
 
@@ -1022,6 +1049,10 @@ Karen Etheridge <ether@cpan.org>
 
 =item *
 
+Michael McClimon <michael@mcclimon.org>
+
+=item *
+
 Niels Thykier <niels@thykier.net>
 
 =item *
@@ -1030,6 +1061,10 @@ Olaf Alders <olaf@wundersolutions.com>
 
 =item *
 
+Ricardo Signes <rjbs@semiotic.systems>
+
+=item *
+
 Roman Hubacek <roman.hubacek@centrum.cz>
 
 =item *
